@@ -15,9 +15,13 @@ class FilesManager:
             song_name = os.path.splitext(filename)[0]
             f = music_tag.load_file(filepath)
             f["title"] = song_name
-            f["artist"] = self.args.artist
+            for artist in self.args.artists:
+                f.append_tag("artist", artist)
             f["album"] = self.args.album
             f.save()
-            dest_dir = f"./{self.args.artist or UNKNOWN}/{self.args.album or UNKNOWN}"
+            dest_dir = "./{}/{}".format(
+                " X ".join(self.args.artists) or UNKNOWN,
+                self.args.album or UNKNOWN,
+            )
             os.makedirs(dest_dir, exist_ok=True)
             shutil.move(filepath, os.path.join(dest_dir, filename))
